@@ -30,7 +30,7 @@ class Cluster(resource.Resource):
     patch_update = True
 
     _query_mapping = resource.QueryParameters(
-        'name', 'status', 'sort', 'global_project')
+        'name', 'status', 'sort', 'global_project', 'profile_only')
 
     # Properties
     #: The name of the cluster.
@@ -74,6 +74,8 @@ class Cluster(resource.Resource):
     node_ids = resource.Body('nodes')
     #: Name of the profile used by the cluster.
     profile_name = resource.Body('profile_name')
+    #: A dictionary with dependency information of the cluster
+    dependents = resource.Body('dependents', type=dict)
 
     def action(self, session, body):
         url = utils.urljoin(self.base_path, self._get_id(self), 'actions')
@@ -88,9 +90,17 @@ class Cluster(resource.Resource):
         }
         return self.action(session, body)
 
-    def del_nodes(self, session, nodes):
+    def del_nodes(self, session, nodes, **params):
+        data = {'nodes': nodes}
+        data.update(params)
         body = {
-            'del_nodes': {
+            'del_nodes': data
+        }
+        return self.action(session, body)
+
+    def replace_nodes(self, session, nodes):
+        body = {
+            'replace_nodes': {
                 'nodes': nodes,
             }
         }
@@ -153,3 +163,17 @@ class Cluster(resource.Resource):
             'recover': params
         }
         return self.action(session, body)
+
+    def op(self, session, operation, **params):
+        """Perform an operation on the cluster.
+
+        :param session: A session object used for sending request.
+        :param operation: A string representing the operation to be performed.
+        :param dict params: An optional dict providing the parameters for the
+                            operation.
+        :returns: A dictionary containing the action ID.
+        """
+        url = utils.urljoin(self.base_path, self.id, 'ops')
+        resp = session.post(url, endpoint_filter=self.service,
+                            json={operation: params})
+        return resp.json()
